@@ -193,15 +193,22 @@ class InteractionContext:
                 "The top level of the components list must be made of ActionRows!"
             )
 
+        if allowed_mentions is not None:
+            if self.bot.allowed_mentions is not None:
+                allowed_mentions = self.bot.allowed_mentions.merge(allowed_mentions).to_dict()
+            else:
+                allowed_mentions = allowed_mentions.to_dict()
+        else:
+            if self.bot.allowed_mentions is not None:
+                allowed_mentions = self.bot.allowed_mentions.to_dict()
+            else:
+                allowed_mentions = {}
+
         base = {
             "content": content,
             "tts": tts,
             "embeds": [x.to_dict() for x in embeds] if embeds else [],
-            "allowed_mentions": allowed_mentions.to_dict()
-            if allowed_mentions
-            else self.bot.allowed_mentions.to_dict()
-            if self.bot.allowed_mentions
-            else {},
+            "allowed_mentions": allowed_mentions,
             "components": components or [],
         }
         if hidden:
@@ -380,42 +387,71 @@ class ComponentContext(InteractionContext):
         """
         _resp = {}
 
-        content = fields.get("content")
-        if content:
-            _resp["content"] = str(content)
+        try:
+            content = fields["content"]
+        except KeyError:
+            pass
+        else:
+            if content is not None:
+                content = str(content)
+            _resp["content"] = content
+
+        try:
+            components = fields["components"]
+        except KeyError:
+            pass
+        else:
+            if components is None:
+                _resp["components"] = []
+            else:
+                _resp["components"] = components
+
+        try:
+            embeds = fields["embeds"]
+        except KeyError:
+            # Nope
+            pass
+        else:
+            if not isinstance(embeds, list):
+                raise error.IncorrectFormat("Provide a list of embeds.")
+            if len(embeds) > 10:
+                raise error.IncorrectFormat("Do not provide more than 10 embeds.")
+            _resp["embeds"] = [e.to_dict() for e in embeds]
+
+        try:
+            embed = fields["embed"]
+        except KeyError:
+            pass
+        else:
+            if "embeds" in _resp:
+                raise error.IncorrectFormat("You can't use both `embed` and `embeds`!")
+
+            if embed is None:
+                _resp["embeds"] = []
+            else:
+                _resp["embeds"] = [embed.to_dict()]
 
-        embed = fields.get("embed")
-        embeds = fields.get("embeds")
         file = fields.get("file")
         files = fields.get("files")
-        components = fields.get("components")
 
-        if components:
-            _resp["components"] = components
-
-        if embed and embeds:
-            raise error.IncorrectFormat("You can't use both `embed` and `embeds`!")
-        if file and files:
+        if files is not None and file is not None:
             raise error.IncorrectFormat("You can't use both `file` and `files`!")
         if file:
             files = [file]
-        if embed:
-            embeds = [embed]
-        if embeds:
-            if not isinstance(embeds, list):
-                raise error.IncorrectFormat("Provide a list of embeds.")
-            elif len(embeds) > 10:
-                raise error.IncorrectFormat("Do not provide more than 10 embeds.")
-            _resp["embeds"] = [x.to_dict() for x in embeds]
 
         allowed_mentions = fields.get("allowed_mentions")
-        _resp["allowed_mentions"] = (
-            allowed_mentions.to_dict()
-            if allowed_mentions
-            else self.bot.allowed_mentions.to_dict()
-            if self.bot.allowed_mentions
-            else {}
-        )
+        if allowed_mentions is not None:
+            if self.bot.allowed_mentions is not None:
+                _resp["allowed_mentions"] = self.bot.allowed_mentions.merge(
+                    allowed_mentions
+                ).to_dict()
+            else:
+                _resp["allowed_mentions"] = allowed_mentions.to_dict()
+        else:
+            if self.bot.allowed_mentions is not None:
+                _resp["allowed_mentions"] = self.bot.allowed_mentions.to_dict()
+            else:
+                _resp["allowed_mentions"] = {}
 
         if not self.responded:
             if files and not self.deferred:
